@@ -90,11 +90,13 @@ static void unity_trace_log_object (GObject *obj, const gchar *format, ...) { ;
 #endif /* ENABLE_UNITY_TRACE_LOG */
 
 #ifdef ENABLE_LTTNG
+void     unity_trace_tracepoint_va (const gchar *format, va_list args);
+
 static void unity_trace_tracepoint (const gchar *format, ...)
 {
   va_list args;
   va_start (args, format);
-  unity_trace_tracepoint_real (format, args);
+  unity_trace_tracepoint_va (format, args);
   va_end (args);
 }
 #else
